@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 class NodeNotReadyError(Exception):
     pass
 
@@ -15,11 +18,11 @@ class NodesNotHealthyConditionError(Exception):
 
 
 class CommandExecFailed(Exception):
-    def __init__(self, name, err=None):
+    def __init__(self, name: str, err: str = "") -> None:
         self.name = name
         self.err = f"Error: {err}" if err else ""
 
-    def __str__(self):
+    def __str__(self) -> str:
         return f"Command: {self.name} - exec failed. {self.err}"
 
 
